API Reference
============

This section provides detailed API documentation for the various modules in the Podcast Teaser Generator.

Main Module
----------

.. automodule:: podcast_teaser
   :members:
   :undoc-members:
   :show-inheritance:

Configuration
-----------

.. automodule:: src.config
   :members:
   :undoc-members:
   :show-inheritance:

Audio Analysis
------------

.. automodule:: src.analysis
   :members:
   :undoc-members:
   :show-inheritance:

Teaser Generation
---------------

.. automodule:: src.generator
   :members:
   :undoc-members:
   :show-inheritance:

Transcription
-----------

.. automodule:: src.transcription
   :members:
   :undoc-members:
   :show-inheritance:

Text Utilities
------------

.. automodule:: src.text_utils
   :members:
   :undoc-members:
   :show-inheritance:

Visualization
-----------

.. automodule:: src.visualization
   :members:
   :undoc-members:
   :show-inheritance:

Logging
------

.. automodule:: src.logger
   :members:
   :undoc-members:
   :show-inheritance:

Default Settings
--------------

.. automodule:: src.defaults
   :members:
   :undoc-members:
   :show-inheritance:
